import React, { useState, useEffect, useCallback } from "react";
import "../../css/style.css";

function FAQ({ initialFaqs = [], onFaqsChange, errors }) {
    const [faqs, setFaqs] = useState(initialFaqs);

    //  console.log(faqs, "faikjk98qs");

    const stableOnFaqsChange = useCallback(onFaqsChange, []);

    useEffect(() => {
        stableOnFaqsChange(faqs);
    }, [faqs, stableOnFaqsChange]);

    const addFAQ = () => {
        setFaqs([...faqs, { question: "", answer: "" }]);
    };

    const removeFAQ = (index) => {
        const updatedFaqs = [...faqs];
        updatedFaqs.splice(index, 1);
        setFaqs(updatedFaqs);
    };

    const handleQuestionChange = (index, e) => {
        const updatedFaqs = [...faqs];
        updatedFaqs[index].question = e.target.value;
        setFaqs(updatedFaqs);
    };

    const handleAnswerChange = (index, e) => {
        const updatedFaqs = [...faqs];
        updatedFaqs[index].answer = e.target.value;
        setFaqs(updatedFaqs);
    };

    return (
        <div>
            {faqs.map((faq, index) => (
                <div key={index} className="form-group mt-4">
                    <label className="fw-bold" style={{ fontSize: "14px" }}>
                        Add an FAQ
                    </label>
                    <input
                        className="inputElement input-field w-100 border inputshadow"
                        placeholder="Add your question here"
                        name="question"
                        value={faq.question}
                        onChange={(e) => handleQuestionChange(index, e)}
                        style={{ marginBottom: "12px" }}
                    />
                    {errors?.question && (
                        <div className="text-danger">{errors.question}</div>
                    )}
                    <textarea
                        className="textarea-field w-100 border inputshadow"
                        name="answer"
                        placeholder="Add your answer here"
                        value={faq.answer}
                        onChange={(e) => handleAnswerChange(index, e)}
                    />
                    {errors?.answer && (
                        <div className="text-danger">{errors.answer}</div>
                    )}
                    <div className="">
                        <button
                            type="button"
                            className="faqremove-btn float-right mb-3"
                            onClick={() => removeFAQ(index)}
                        >
                            <img
                                style={{ height: "30px" }}
                                src="/images/delbtn.png"
                                alt="Delete Button"
                            />
                        </button>
                    </div>
                </div>
            ))}
            <div className="d-flex justify-content-end ">
                <button
                    type="button"
                    className="border mt-4 p-2 rounded-3"
                    style={{ fontSize: "14px" }}
                    onClick={addFAQ}
                >
                    + Add FAQ
                </button>
            </div>
        </div>
    );
}

export default FAQ;
